@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.496";
+our $VERSION = "0.497";
 
 1;
 
@@ -421,12 +421,14 @@ Calls the L<recv|SPVM::Sys::Socket/"recv"> method in the L<Sys::Socket|SPVM::Sys
 
 =head2 send
 
-C<static method send : int ($sockfd : int, $buf : string, $flags : int, $addr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> = undef, $buf_offset : int = 0)>
+C<static method send : int ($sockfd : int, $buf : string, $flags : int, $addr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> = undef, $len : int = -1, $buf_offset : int = 0)>
 
 If $addr is defined, calls the L<sendto|SPVM::Sys::Socket/"sendto"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
 Otherwise calls the L<send|SPVM::Sys::Socket/"send"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
+If $len is less than 0, The length of $buffer is set to $len.
+
 =head2 shutdown
 
 C<static method shutdown : int ($sockfd : int, $how : int);>
